==> record_api-1.1.2.tar.gz: record_api-1.1.2/data/typing/pandas.core.arrays.integer.py <==
from typing import *


class Int16Dtype:
    def __eq__(self, _0: Union[Type[numpy.object_], numpy.dtype], /):
        """
        usage.pandas: 9
        """
        ...

    def __ne__(self, _0: numpy.dtype, /):
        """
        usage.pandas: 1
        """
        ...


class Int32Dtype:
    def __eq__(self, _0: Union[Type[numpy.object_], numpy.dtype], /):
        """
        usage.pandas: 9
        """
        ...

    def __ne__(self, _0: numpy.dtype, /):
        """
        usage.pandas: 1
        """
        ...


class Int64Dtype:
    def __eq__(self, _0: Union[numpy.dtype, Type[numpy.object_]], /):
        """
        usage.pandas: 9
        """
        ...

    def __ne__(self, _0: numpy.dtype, /):
        """
        usage.pandas: 1
        """
        ...


class Int8Dtype:
    def __eq__(self, _0: Union[Type[numpy.object_], numpy.dtype], /):
        """
        usage.pandas: 9
        """
        ...

    def __ne__(self, _0: numpy.dtype, /):
        """
        usage.pandas: 1
        """
        ...


class IntegerArray:
    def __add__(self, _0: numpy.ndarray, /):
        """
        usage.pandas: 2
        """
        ...

    def __eq__(self, _0: object, /):
        """
        usage.pandas: 9
        """
        ...

    def __radd__(self, _0: object, /):
        """
        usage.pandas: 19
        """
        ...

    def __rfloordiv__(self, _0: object, /):
        """
        usage.pandas: 19
        """
        ...

    def __rmod__(self, _0: object, /):
        """
        usage.pandas: 19
        """
        ...

    def __rmul__(self, _0: object, /):
        """
        usage.pandas: 19
        """
        ...

    def __rpow__(self, _0: object, /):
        """
        usage.pandas: 20
        """
        ...

    def __rsub__(self, _0: object, /):
        """
        usage.pandas: 15
        """
        ...

    def __rtruediv__(self, _0: object, /):
        """
        usage.pandas: 19
        """
        ...


class UInt16Dtype:
    def __eq__(self, _0: Union[Type[numpy.object_], numpy.dtype], /):
        """
        usage.pandas: 9
        """
        ...

    def __ne__(self, _0: numpy.dtype, /):
        """
        usage.pandas: 1
        """
        ...


class UInt32Dtype:
    def __eq__(self, _0: Union[Type[numpy.object_], numpy.dtype], /):
        """
        usage.pandas: 9
        """
        ...

    def __ne__(self, _0: numpy.dtype, /):
        """
        usage.pandas: 1
        """
        ...


class UInt64Dtype:
    def __eq__(self, _0: Union[Type[numpy.object_], numpy.dtype], /):
        """
        usage.pandas: 9
        """
        ...

    def __ne__(self, _0: numpy.dtype, /):
        """
        usage.pandas: 1
        """
        ...


class UInt8Dtype:
    def __eq__(self, _0: Union[Type[numpy.object_], numpy.dtype], /):
        """
        usage.pandas: 9
        """
        ...

    def __ne__(self, _0: numpy.dtype, /):
        """
        usage.pandas: 1
        """
        ...

==> record_api-1.2.0.tar.gz: record_api-1.2.0/data/typing/pandas.core.arrays.integer.py <==
from typing import *


class Int16Dtype:

    # usage.sklearn: 1
    kind: object

    # usage.sklearn: 1
    name: object

    def __eq__(self, _0: Union[Type[numpy.object_], numpy.dtype], /):
        """
        usage.pandas: 9
        """
        ...

    def __ne__(self, _0: numpy.dtype, /):
        """
        usage.pandas: 1
        """
        ...


class Int32Dtype:
    def __init__(self, /):
        """
        usage.dask: 1
        """
        ...

    def __eq__(self, _0: Union[Type[numpy.object_], numpy.dtype], /):
        """
        usage.pandas: 9
        """
        ...

    def __ne__(self, _0: numpy.dtype, /):
        """
        usage.pandas: 1
        """
        ...


class Int64Dtype:
    @classmethod
    def is_dtype(cls, /, dtype: pandas.core.series.Series):
        """
        usage.dask: 1
        """
        ...

    # usage.dask: 1
    kind: object

    def __eq__(self, _0: Union[numpy.dtype, Type[numpy.object_]], /):
        """
        usage.pandas: 9
        """
        ...

    def __ne__(self, _0: numpy.dtype, /):
        """
        usage.pandas: 1
        """
        ...


class Int8Dtype:

    # usage.sklearn: 1
    kind: object

    # usage.sklearn: 1
    name: object

    def __eq__(self, _0: Union[Type[numpy.object_], numpy.dtype], /):
        """
        usage.pandas: 9
        """
        ...

    def __ne__(self, _0: numpy.dtype, /):
        """
        usage.pandas: 1
        """
        ...


class IntegerArray:

    # usage.dask: 1
    __module__: ClassVar[object]

    def __add__(self, _0: numpy.ndarray, /):
        """
        usage.pandas: 2
        """
        ...

    def __eq__(self, _0: object, /):
        """
        usage.pandas: 9
        """
        ...

    def __radd__(self, _0: object, /):
        """
        usage.pandas: 19
        """
        ...

    def __rfloordiv__(self, _0: object, /):
        """
        usage.pandas: 19
        """
        ...

    def __rmod__(self, _0: object, /):
        """
        usage.pandas: 19
        """
        ...

    def __rmul__(self, _0: object, /):
        """
        usage.pandas: 19
        """
        ...

    def __rpow__(self, _0: object, /):
        """
        usage.pandas: 20
        """
        ...

    def __rsub__(self, _0: object, /):
        """
        usage.pandas: 15
        """
        ...

    def __rtruediv__(self, _0: object, /):
        """
        usage.pandas: 19
        """
        ...


class UInt16Dtype:

    # usage.sklearn: 1
    kind: object

    # usage.sklearn: 1
    name: object

    def __eq__(self, _0: Union[Type[numpy.object_], numpy.dtype], /):
        """
        usage.pandas: 9
        """
        ...

    def __ne__(self, _0: numpy.dtype, /):
        """
        usage.pandas: 1
        """
        ...


class UInt32Dtype:
    def __eq__(self, _0: Union[Type[numpy.object_], numpy.dtype], /):
        """
        usage.pandas: 9
        """
        ...

    def __ne__(self, _0: numpy.dtype, /):
        """
        usage.pandas: 1
        """
        ...


class UInt64Dtype:
    def __eq__(self, _0: Union[Type[numpy.object_], numpy.dtype], /):
        """
        usage.pandas: 9
        """
        ...

    def __ne__(self, _0: numpy.dtype, /):
        """
        usage.pandas: 1
        """
        ...


class UInt8Dtype:

    # usage.sklearn: 1
    kind: object

    # usage.sklearn: 1
    name: object

    def __eq__(self, _0: Union[Type[numpy.object_], numpy.dtype], /):
        """
        usage.pandas: 9
        """
        ...

    def __ne__(self, _0: numpy.dtype, /):
        """
        usage.pandas: 1
        """
        ...
